@@ -112,6 +112,7 @@ class OxfordTextLoader(EBSDDataLoader):
             phase = Phase(
                 lineSplit[2],
                 int(lineSplit[3]),
+                int(lineSplit[4]),
                 latticeParams
             )
             return phase
@@ -149,6 +150,9 @@ class OxfordTextLoader(EBSDDataLoader):
             *(np.array(acqEulers) * np.pi / 180)
         )
 
+        # TODO: Load EDX data from .ctf file, if it's accesible
+        self.loadedMetadata['EDX Windows'] = {'Count': int(0)}
+
         self.checkMetadata()
 
         # Construct data format from table header
@@ -297,6 +301,7 @@ class OxfordBinaryLoader(EBSDDataLoader):
             self.loadedMetadata['phases'].append(Phase(
                 phaseMetadata['StructureName'],
                 int(phaseMetadata['LaueGroup']),
+                int(phaseMetadata['SpaceGroup']),
                 (
                     round(float(phaseMetadata['a']), 3),
                     round(float(phaseMetadata['b']), 3),
@@ -306,19 +311,22 @@ class OxfordBinaryLoader(EBSDDataLoader):
                     round(float(phaseMetadata['gamma']), 3) * np.pi / 180
                 )
             ))
-
+ 
         # Deal with EDX data
+        edx_fields = {}
         if 'EDX Windows' in metadata:
-            edx_dict = metadata['EDX Windows']
-            num_edx = int(edx_dict['Count'])
+            self.loadedMetadata['EDX Windows'] = metadata['EDX Windows']
             edx_fields = {}
-            for i in range(1, num_edx + 1):
-                key = f"Window{i}"
-                edx_fields[100+i] = (f'EDX {edx_dict[key]}', 'float32')
+            for i in range(1, int(self.loadedMetadata['EDX Windows']['Count']) + 1):
+                name = self.loadedMetadata['EDX Windows'][f"Window{i}"]
+                edx_fields[100+i] = (f'EDX {name}', 'float32')
+        else:
+            self.loadedMetadata['EDX Windows'] = {'Count': int(0)}
 
         self.checkMetadata()
 
         # Construct binary data format from listed fields
+        unknown_field_count = 0
         dataFormat = [('phase', 'uint8')]
         fieldLookup = {
             3: ('ph1', 'float32'),
@@ -337,7 +345,10 @@ class OxfordBinaryLoader(EBSDDataLoader):
                 fieldID = int(metadata['Fields']['Field{:}'.format(i + 1)])
                 dataFormat.append(fieldLookup[fieldID])
         except KeyError:
-            raise TypeError("Unknown data in EBSD file.")
+            print(f'\nUnknown field in file with key {fieldID}. '
+                  f'Assumming float32 data.')
+            unknown_field_count += 1
+            dataFormat.append((f'unknown_{unknown_field_count}', 'float32'))
 
         self.dataFormat = np.dtype(dataFormat)
 
@@ -378,6 +389,14 @@ class OxfordBinaryLoader(EBSDDataLoader):
         eulerAngles = np.reshape(
             binData[['ph1', 'phi', 'ph2']], (yDim, xDim)
         )
+
+        # Load EDX data into a dict
+        if int(self.loadedMetadata['EDX Windows']['Count']) > 0:
+            EDXFields = [key for key in binData.dtype.fields.keys() if key.startswith('EDX')]        
+            self.loadedData['EDXDict'] = dict(
+                [(field[4:], np.reshape(binData[field], (yDim, xDim))) for field in EDXFields]
+                )
+
         # flatten the structures so that the Euler angles are stored
         # into a normal array
         eulerAngles = np.array(eulerAngles.tolist()).transpose((2, 0, 1))
@@ -406,6 +425,7 @@ class PythonDictLoader(EBSDDataLoader):
         self.loadedMetadata['stepSize'] = dataDict['stepSize']
         assert type(dataDict['phases']) is list
         self.loadedMetadata['phases'] = dataDict['phases']
+        self.loadedMetadata['EDX Windows'] = {'Count': int(0)}
 
         self.checkMetadata()
 
